# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, lib, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      # Include the home-manager configuration
      <home-manager/nixos>
    ];

  # Bootloader.
  boot.supportedFilesystems = [ "nfs" ];
  boot.kernelModules = [ "nfs" ];
  # Disable PSR according to
  # https://bbs.archlinux.org/viewtopic.php?pid=2191514#p2191514
  boot.kernelParams = [
    "amdgpu.dcdebugmask=0x12"
  ];
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  # Configure console keymap
  console.keyMap = "us";

  environment.etc."nginx/certs/sovr.crt" = {
    source = ./certs/sovr.crt;
  };
  environment.etc."nginx/certs/sovr.key" = {
    source = ./certs/sovr.key;
  };
  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    aerc
    brgenml1lpr
    brgenml1cupswrapper
    brlaser
    cargo
    chezmoi
    cups-filters
    devenv
    dia
    dig
    fish
    fractal
    freetube
    gcc
    google-cloud-sdk
    gimp-with-plugins
    git
    gnumake
    gutenprint
    gutenprintBin
    hmcl
    hplip
    kdePackages.plasma-browser-integration
    keychain
    libation
    lm_sensors
    lunar-client
    mosh
    mercurial
    mumble
    ndisc6
    nfs-utils
    neovim
    nginx
    om4
    poetry
    python3
    remmina
    rustc
    signal-desktop
    splix
    spotify-player
    s-tui
    step-ca
    step-cli
    thunderbird
    tig
    tmux
    ungoogled-chromium
    usbutils
    wget
    websocat
    vlc
  ];

  # Bluetooth
  hardware.bluetooth.enable = true; # enables support for Bluetooth
  hardware.bluetooth.powerOnBoot = true; # powers up the default Bluetooth controller on boot
  hardware.pulseaudio.enable = false;

  home-manager.useGlobalPkgs = true;
  home-manager.users.eliribble = {
    home.homeDirectory = "/home/eliribble";
    # The home.stateVersion option does not have a default and must be set
    home.stateVersion = "24.11";
    home.username = "eliribble";
    home.file.".config/fish/functions/fish_prompt.fish".source = ./home/eliribble/config/fish/functions/fish_prompt.fish;
    home.file.".config/nvim/after/ftplugin/html.vim".source = ./home/eliribble/config/nvim/after/ftplugin/html.vim;
    home.file.".config/nvim/after/ftplugin/go.vim".source = ./home/eliribble/config/nvim/after/ftplugin/go.vim;
    home.file.".config/tmux/tmux.conf".source = ./home/eliribble/config/tmux/tmux.conf;
    programs.fish = {
      enable = true;
      interactiveShellInit = ''
        set fish_greeting # Disable greeting
      '';
      #plugins = [
       #{ name = "grc"; src = pkgs.fishPlugins.grc.src; }
      #];
    };
    programs.git = {
      enable = true;
      package = pkgs.gitFull;
      userName = "Eli Ribble";
      userEmail = "eli@theribbles.org";
    };
  };
  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "en_US.UTF-8";
    LC_IDENTIFICATION = "en_US.UTF-8";
    LC_MEASUREMENT = "en_US.UTF-8";
    LC_MONETARY = "en_US.UTF-8";
    LC_NAME = "en_US.UTF-8";
    LC_NUMERIC = "en_US.UTF-8";
    LC_PAPER = "en_US.UTF-8";
    LC_TELEPHONE = "en_US.UTF-8";
    LC_TIME = "en_US.UTF-8";
  };

  networking.extraHosts = ''
  192.168.1.5 pihole.home.arpa
  127.0.0.1 sovr.home.arpa
  '';
  # Open ports in the firewall.
  networking.firewall.allowedTCPPorts = [ 5353 50007 ];
  networking.firewall.allowedUDPPorts = [ 5353 50007 ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  networking.hostName = "nalai"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;

  nix.extraOptions = ''
    trusted-users = root eliribble
  '';
  nix.settings.experimental-features = [ "flakes" "nix-command" ];


  nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
    "brgenml1lpr" "lunarclient"
  ];

  # Set up Android dev tools
  programs.adb.enable = true;
  # Integrate Chromium with Plasma
  programs.chromium.enablePlasmaBrowserIntegration = true;

  # Set neovim as the default editor
  programs.neovim.enable = true;
  programs.neovim.defaultEditor = true;
  programs.thunderbird.enable = true;
  programs.virt-manager.enable = true;

  # Enable printer auto-discovery
  services.avahi = {
    enable = true;
    nssmdns4 = true;
    openFirewall = true;
  };
  # Enable the KDE Plasma Desktop Environment.
  services.displayManager.sddm.enable = true;
  services.desktopManager.plasma6.enable = true;

  services.nginx.enable = true;
  services.nginx.virtualHosts."sovr.home.arpa" = {
    addSSL = true;
    enableACME = false;
    sslCertificate = "/etc/nginx/certs/sovr.crt";
    sslCertificateKey = "/etc/nginx/certs/sovr.key";
    locations."/" = {
      proxyPass = "http://127.0.0.1:8080";
    };
  };

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable rpcbind for nfs mounting
  services.rpcbind.enable = true;

  # Enable the X11 windowing system.
  # You can disable this if you're only using the Wayland session.
  services.xserver.enable = true;

  # Configure keymap in X11
  services.xserver.xkb = {
    layout = "us";
  };

  # Enable sound with pipewire.
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    # If you want to use JACK applications, uncomment this
    #jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };
  services.power-profiles-daemon.enable = false;
  services.resolved.enable = true;
  services.tailscale.enable = true;
  services.tlp = {
    enable = true;
    settings = {
      CPU_SCALING_GOVERNOR_ON_AC = "performance";
      CPU_SCALING_GOVERNOR_ON_BAT = "powersave";

      CPU_ENERGY_PERF_POLICY_ON_BAT = "power";
      CPU_ENERGY_PERF_POLICY_ON_AC = "performance";

      CPU_MIN_PERF_ON_AC = 0;
      CPU_MAX_PERF_ON_AC = 100;
      CPU_MIN_PERF_ON_BAT = 0;
      CPU_MAX_PERF_ON_BAT = 20;

      # Optional helps save long term battery health
      START_CHARGE_THRESH_BAT0 = 40; # 40 and below it starts to charge
      STOP_CHARGE_THRESH_BAT0 = 80; # 80 and above it stops charging
    };
  };
  services.thinkfan = {
    enable = true;
  };

  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;

  systemd.network.enable = true;
  systemd.network.wait-online.enable = false;

  # Set your time zone.
  time.timeZone = "America/Phoenix";

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.eliribble = {
    isNormalUser = true;
    description = "Eli Ribble";
    extraGroups = [ "adbusers" "libvirtd" "networkmanager" "wheel" ];
    packages = with pkgs; [
      kdePackages.kate
    #  thunderbird
    ];
  };

  virtualisation.docker.enable = false;
  virtualisation.libvirtd.enable = true;
  virtualisation.podman.enable = true;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "24.05"; # Did you read the comment?
}
